@@ -4,4 +4,4 @@
 CROSS_ENCODER = "cross-encoder/ms-marco-TinyBERT-L-2-v2"
 BI_ENCODER = "retrieve_rank"
 INDEX="faiss_index"
-DATA="https://github.com/Nandhagopalan/Semanticsearch/releases/download/0.0.2/covid_papers.csv"
+DATA="data"
