@@ -64,12 +64,14 @@ def get_model(embedder,faissix,data):
 
         os.remove("search.index.zip")
 
-    if not os.path.isfile('data/covid_papers.csv'):
-        urllib.request.urlretrieve(models[data].url, "data/covid_papers.csv")
+    if not os.path.isfile('covid_papers.csv'):
+        urllib.request.urlretrieve(models[data].url, "covid_papers.csv")
 
-    data=pd.read_csv('data/covid_papers.csv')
+    data=pd.read_csv('covid_papers.csv')
     passages=data['abstract'].values.tolist()
 
+    os.remove("covid_papers.csv")
+
     index=models[faissix].model.read_index('../model/search.index')
     
     return model_class,index,passages
